==> harbour-2.0.0.tar.gz: harbour-2.0.0/src/codepage/cpcswin.c <==
/*
 * $Id: cpcswin.c 12871 2009-11-14 04:07:58Z vszakats $
 */

/*
 * Harbour Project source code:
 * National Collation Support Module ( CSWIN )
 *
 * Copyright 2002 Alexander S.Kresin <alex@belacy.belgorod.su>
 * www - http://www.harbour-project.org
 * Czech collating sequence (CSWIN) done by Vojtech Obrdlik <vobrdlik@centrum.cz>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2, or (at your option)
 * any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this software; see the file COPYING.  If not, write to
 * the Free Software Foundation, Inc., 59 Temple Place, Suite 330,
 * Boston, MA 02111-1307 USA (or visit the web site http://www.gnu.org/).
 *
 * As a special exception, the Harbour Project gives permission for
 * additional uses of the text contained in its release of Harbour.
 *
 * The exception is that, if you link the Harbour libraries with other
 * files to produce an executable, this does not by itself cause the
 * resulting executable to be covered by the GNU General Public License.
 * Your use of that executable is in no way restricted on account of
 * linking the Harbour library code into it.
 *
 * This exception does not however invalidate any other reasons why
 * the executable file might be covered by the GNU General Public License.
 *
 * This exception applies only to the code released by the Harbour
 * Project under the name Harbour.  If you copy code from other
 * Harbour Project or Free Software Foundation releases into a copy of
 * Harbour, as the General Public License permits, the exception does
 * not apply to the code that you add in this way.  To avoid misleading
 * anyone as to the status of such modified files, you must delete
 * this exception notice from them.
 *
 * If you write modifications of your own for Harbour, it is your choice
 * whether to permit this exception to apply to your modifications.
 * If you do not wish that, delete this exception notice.
 *
 */

#define HB_CP_ID        CSWIN
#define HB_CP_INFO      "Czech Windows-1250"
#define HB_CP_UNITB     HB_UNITB_1250
#define HB_CP_ACSORT    HB_CDP_ACSORT_INTERLEAVED
#define HB_CP_UPPER     "A~~BCD~E~~~FGH.CH.I~JKLMN~O~~PQRST~U~~~VWXY~Z"
#define HB_CP_LOWER     "a~~bcd~e~~~fgh.ch.i~jklmn~o~~pqrst~u~~~vwxy~z"

/* include CP registration code */
#include "hbcdpreg.h"

==> harbour-3.0.0.tar.gz: harbour-3.0.0/src/codepage/cpcswin.c <==
/*
 * $Id: cpcswin.c 15908 2010-12-02 10:20:06Z druzus $
 */

/*
 * Harbour Project source code:
 * National Collation Support Module ( CSWIN )
 *
 * Copyright 2002 Alexander S.Kresin <alex@belacy.belgorod.su>
 * www - http://harbour-project.org
 * Czech collating sequence (CSWIN) done by Vojtech Obrdlik <vobrdlik@centrum.cz>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2, or (at your option)
 * any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this software; see the file COPYING.  If not, write to
 * the Free Software Foundation, Inc., 59 Temple Place, Suite 330,
 * Boston, MA 02111-1307 USA (or visit the web site http://www.gnu.org/).
 *
 * As a special exception, the Harbour Project gives permission for
 * additional uses of the text contained in its release of Harbour.
 *
 * The exception is that, if you link the Harbour libraries with other
 * files to produce an executable, this does not by itself cause the
 * resulting executable to be covered by the GNU General Public License.
 * Your use of that executable is in no way restricted on account of
 * linking the Harbour library code into it.
 *
 * This exception does not however invalidate any other reasons why
 * the executable file might be covered by the GNU General Public License.
 *
 * This exception applies only to the code released by the Harbour
 * Project under the name Harbour.  If you copy code from other
 * Harbour Project or Free Software Foundation releases into a copy of
 * Harbour, as the General Public License permits, the exception does
 * not apply to the code that you add in this way.  To avoid misleading
 * anyone as to the status of such modified files, you must delete
 * this exception notice from them.
 *
 * If you write modifications of your own for Harbour, it is your choice
 * whether to permit this exception to apply to your modifications.
 * If you do not wish that, delete this exception notice.
 *
 */

#define HB_CP_ID        CSWIN
#define HB_CP_INFO      "Czech Windows-1250"
#define HB_CP_UNITB     HB_UNITB_1250
#define HB_CP_ACSORT    HB_CDP_ACSORT_NONE
#define HB_CP_UPPER     "ABCDEFGH.CH.IJKLMNOPQRSTUVWXYZ"
#define HB_CP_LOWER     "abcdefgh.ch.ijklmnopqrstuvwxyz"

/* include CP registration code */
#include "hbcdpreg.h"
